<!DOCTYPE html>
<html lang="en">

<head>
<meta charset="utf-8">
<title>Willies - Real Estate HTML Template | Home Page 02</title>
<!-- Stylesheets -->
<link href="css/bootstrap.css" rel="stylesheet">
<link href="css/style.css" rel="stylesheet">
<link href="css/responsive.css" rel="stylesheet">
<!--Color Switcher Mockup-->
<link href="css/color-switcher-design.css" rel="stylesheet">
<!--Color Themes-->
<link id="theme-color-file" href="css/color-themes/default-theme.css" rel="stylesheet">

<link rel="shortcut icon" href="images/favicon.png" type="image/x-icon">
<link rel="icon" href="images/favicon.png" type="image/x-icon">
<!-- Responsive -->
<meta http-equiv="X-UA-Compatible" content="IE=edge">
<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=0">
<!--[if lt IE 9]><script src="https://cdnjs.cloudflare.com/ajax/libs/html5shiv/3.7.3/html5shiv.js"></script><![endif]-->
<!--[if lt IE 9]><script src="js/respond.js"></script><![endif]-->
</head>

<body>

<div class="page-wrapper">
    <!-- Preloader -->
    <div class="preloader"></div>
    
    <!-- Main Header-->
    <header class="main-header header-style-two">
        <!--Header Top-->
        <div class="header-top">
            <div class="auto-container">
                <div class="inner-container clearfix">
                    <div class="top-left">
                        <ul class="contact-list clearfix">
                            <li><i class="la la-home"></i> 256 Interior the good, New York</li>
                            <li><i class="la la-envelope-o"></i><a href="#">Supportyou@Interiores.com</a></li>
                        </ul>
                    </div>
                    <div class="top-right">
                        <ul class="social-icon-one clearfix">
                            <li><a href="#"><i class="la la-facebook-f"></i></a></li>
                            <li><a href="#"><i class="la la-twitter"></i></a></li>
                            <li><a href="#"><i class="la la-google-plus"></i></a></li>
                            <li><a href="#"><i class="la la-dribbble"></i></a></li>
                            <li><a href="#"><i class="la la-pinterest"></i></a></li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
        <!-- End Header Top -->

        <!-- Header Lower -->
        <div class="header-lower">
            <div class="auto-container">
                <div class="main-box">
                    <div class="inner-container clearfix">
                        <div class="logo-box">
                            <div class="logo"><a href="index-2.html"><img src="images/logo-2.png" alt="" title=""></a></div>
                        </div>

                        <div class="nav-outer clearfix">
                            <!-- Main Menu -->
                            <nav class="main-menu navbar-expand-md navbar-light">
                                <div class="navbar-header">
                                    <!-- Toggle Button -->      
                                    <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="Toggle navigation">
                                        <span class="icon flaticon-menu"></span>
                                    </button>
                                </div>
                                
                                <div class="collapse navbar-collapse clearfix" id="navbarSupportedContent">
                                    <ul class="navigation clearfix">
                                        <li class="current dropdown"><a href="#">Home</a>
                                            <ul>
                                                <li class="dropdown"><a href="#">Header Styles</a>
                                                    <ul>
                                                        <li><a href="index-2.html">Header Style One</a></li>
                                                        <li><a href="index-3.html">Header Style Two</a></li>
                                                        <li><a href="index-4.html">Header Style three</a></li>
                                                        <li><a href="index-5.html">Header Style Four</a></li>
                                                        <li><a href="index-6.html">Header Style Five</a></li>
                                                        <li><a href="index-7.html">Header Style Six</a></li>
                                                    </ul>
                                                </li>
                                                <li><a href="index-2.html">Home page 01</a></li>
                                                <li><a href="index-3.html">Home page 02</a></li>
                                                <li><a href="index-4.html">Home page 03</a></li>
                                                <li><a href="index-5.html">Home page 04</a></li>
                                                <li><a href="index-6.html">Home page 05</a></li>
                                                <li><a href="index-7.html">Home page 06</a></li>
                                            </ul>
                                        </li>
                                        <li class="dropdown"><a href="#">About</a>
                                            <ul>
                                                <li><a href="about.html">About Us</a></li>
                                                <li><a href="faq.html">FAQ's</a></li>
                                                <li><a href="testimonial.html">Testimonials</a></li>
                                            </ul>
                                        </li>
                                        <li class="dropdown"><a href="#">Agents</a>
                                            <ul>
                                                <li><a href="agents.html">Agents</a></li>
                                                <li><a href="agent-detail.html">Agent Detail</a></li>
                                            </ul>
                                        </li>
                                        <li class="dropdown"><a href="#">Properties</a>
                                            <ul>
                                                <li><a href="properties.html">Properties</a></li>
                                                <li><a href="property-list-view.html">Property List View</a></li>
                                                <li><a href="property-grid-view.html">Property Grid View</a></li>
                                                <li><a href="property-modern-view.html">Property Modern View</a></li>
                                                <li><a href="property-detail.html">Property Detail</a></li>
                                            </ul>
                                        </li>
                                        <li class="dropdown"><a href="#">Blog</a>
                                            <ul>
                                                <li><a href="blog.html">Blog Default</a></li>
                                                <li><a href="blog-list.html">Blog List View</a></li>
                                                <li><a href="blog-grid.html">Blog Grid View</a></li>
                                                <li><a href="blog-detail.html">Blog Detail</a></li>
                                            </ul>
                                        </li>
                                        <li><a href="contact.html">Contact</a></li>
                                        <li class="dropdown has-mega-menu"><a href="#">Pages</a>
                                            <div class="mega-menu">
                                                <div class="mega-menu-bar row clearfix">
                                                    <div class="column col-lg-3 col-md-3 col-sm-12">
                                                        <h3>About Us</h3>
                                                        <ul>
                                                            <li><a href="about.html">About Us</a></li>
                                                            <li><a href="agents.html">Agents</a></li>
                                                            <li><a href="agent-detail.html">Agent Detail</a></li>
                                                            <li><a href="faq.html">FAQ's</a></li>
                                                            <li><a href="testimonial.html">Testimonials</a></li>
                                                        </ul>
                                                    </div>
                                                    <div class="column col-lg-3 col-md-3 col-sm-12">
                                                        <h3>Properties</h3>
                                                        <ul>
                                                            <li><a href="properties.html">Properties</a></li>
                                                            <li><a href="property-list-view.html">Property List View</a></li>
                                                            <li><a href="property-grid-view.html">Property Grid View</a></li>
                                                            <li><a href="property-modern-view.html">Property Modern View</a></li>
                                                            <li><a href="property-detail.html">Property Detail</a></li>
                                                        </ul>
                                                    </div>
                                                    <div class="column col-lg-3 col-md-3 col-sm-12">
                                                        <h3>Blog</h3>
                                                        <ul>
                                                            <li><a href="blog.html">Blog Default</a></li>
                                                            <li><a href="blog-list.html">Blog List View</a></li>
                                                            <li><a href="blog-grid.html">Blog Grid View</a></li>
                                                            <li><a href="blog-detail.html">Blog Detail</a></li>
                                                            <li><a href="error-page.html">404 Error Page</a></li>
                                                        </ul>
                                                    </div>
                                                    <div class="column col-lg-3 col-md-3 col-sm-12">
                                                        <h3>Pages</h3>
                                                        <ul>
                                                            <li><a href="admin/submit-property.html">Submit Property</a></li>
                                                            <li><a href="admin/dashboard.html">Dashboard</a></li>
                                                            <li><a href="coming-soon.html">Coming Soon</a></li>
                                                            <li><a href="login.html">Login</a></li>
                                                            <li><a href="contact.html">Contact Us</a></li>
                                                        </ul>
                                                    </div>
                                                </div>
                                            </div>
                                        </li>
                                    </ul>              
                                </div>
                            </nav><!-- Main Menu End-->
                                
                            <!-- Main Menu End-->
                            <div class="outer-box">
                               <div class="btn-box">
                                   <a href="admin/submit-property.html" class="theme-btn btn-style-five">Submit Property</a>
                               </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!--End Header Lower-->

        <!-- Sticky Header  -->
        <div class="sticky-header">
            <div class="auto-container clearfix">
                <!--Logo-->
                <div class="logo pull-left">
                    <a href="index-2.html" title=""><img src="images/logo-small.png" alt="" title=""></a>
                </div>
                <!--Right Col-->
                <div class="pull-right">
                    <!-- Main Menu -->
                    <nav class="main-menu">
                        <div class="navbar-collapse show collapse clearfix">
                            <ul class="navigation clearfix">
                                <li class="current dropdown"><a href="#">Home</a>
                                    <ul>
                                        <li class="dropdown"><a href="#">Header Styles</a>
                                            <ul>
                                                <li><a href="index-2.html">Header Style One</a></li>
                                                <li><a href="index-3.html">Header Style Two</a></li>
                                                <li><a href="index-4.html">Header Style three</a></li>
                                                <li><a href="index-5.html">Header Style Four</a></li>
                                                <li><a href="index-6.html">Header Style Five</a></li>
                                                <li><a href="index-7.html">Header Style Six</a></li>
                                            </ul>
                                        </li>
                                        <li><a href="index-2.html">Home page 01</a></li>
                                        <li><a href="index-3.html">Home page 02</a></li>
                                        <li><a href="index-4.html">Home page 03</a></li>
                                        <li><a href="index-5.html">Home page 04</a></li>
                                        <li><a href="index-6.html">Home page 05</a></li>
                                        <li><a href="index-7.html">Home page 06</a></li>
                                    </ul>
                                </li>
                                <li class="dropdown"><a href="#">About</a>
                                    <ul>
                                        <li><a href="about.html">About Us</a></li>
                                        <li><a href="faq.html">FAQ's</a></li>
                                        <li><a href="testimonial.html">Testimonials</a></li>
                                    </ul>
                                </li>
                                <li class="dropdown"><a href="#">Agents</a>
                                    <ul>
                                        <li><a href="agents.html">Agents</a></li>
                                        <li><a href="agent-detail.html">Agent Detail</a></li>
                                    </ul>
                                </li>
                                <li class="dropdown"><a href="#">Properties</a>
                                    <ul>
                                        <li><a href="properties.html">Properties</a></li>
                                        <li><a href="property-list-view.html">Property List View</a></li>
                                        <li><a href="property-grid-view.html">Property Grid View</a></li>
                                        <li><a href="property-modern-view.html">Property Modern View</a></li>
                                        <li><a href="property-detail.html">Property Detail</a></li>
                                    </ul>
                                </li>
                                <li class="dropdown"><a href="#">Blog</a>
                                    <ul>
                                        <li><a href="blog.html">Blog Default</a></li>
                                        <li><a href="blog-list.html">Blog List View</a></li>
                                        <li><a href="blog-grid.html">Blog Grid View</a></li>
                                        <li><a href="blog-detail.html">Blog Detail</a></li>
                                    </ul>
                                </li>
                                <li><a href="contact.html">Contact</a></li>
                                <li class="dropdown has-mega-menu"><a href="#">Pages</a>
                                    <div class="mega-menu">
                                        <div class="mega-menu-bar row clearfix">
                                            <div class="column col-lg-3 col-md-3 col-sm-12">
                                                <h3>About Us</h3>
                                                <ul>
                                                    <li><a href="about.html">About Us</a></li>
                                                    <li><a href="agents.html">Agents</a></li>
                                                    <li><a href="agent-detail.html">Agent Detail</a></li>
                                                    <li><a href="faq.html">FAQ's</a></li>
                                                    <li><a href="testimonial.html">Testimonials</a></li>
                                                </ul>
                                            </div>
                                            <div class="column col-lg-3 col-md-3 col-sm-12">
                                                <h3>Properties</h3>
                                                <ul>
                                                    <li><a href="properties.html">Properties</a></li>
                                                    <li><a href="property-list-view.html">Property List View</a></li>
                                                    <li><a href="property-grid-view.html">Property Grid View</a></li>
                                                    <li><a href="property-modern-view.html">Property Modern View</a></li>
                                                    <li><a href="property-detail.html">Property Detail</a></li>
                                                </ul>
                                            </div>
                                            <div class="column col-lg-3 col-md-3 col-sm-12">
                                                <h3>Blog</h3>
                                                <ul>
                                                    <li><a href="blog.html">Blog Default</a></li>
                                                    <li><a href="blog-list.html">Blog List View</a></li>
                                                    <li><a href="blog-grid.html">Blog Grid View</a></li>
                                                    <li><a href="blog-detail.html">Blog Detail</a></li>
                                                    <li><a href="error-page.html">404 Error Page</a></li>
                                                </ul>
                                            </div>
                                            <div class="column col-lg-3 col-md-3 col-sm-12">
                                                <h3>Pages</h3>
                                                <ul>
                                                    <li><a href="admin/submit-property.html">Submit Property</a></li>
                                                    <li><a href="admin/dashboard.html">Dashboard</a></li>
                                                    <li><a href="coming-soon.html">Coming Soon</a></li>
                                                    <li><a href="login.html">Login</a></li>
                                                    <li><a href="contact.html">Contact Us</a></li>
                                                </ul>
                                            </div>
                                        </div>
                                    </div>
                                </li>
                            </ul>
                        </div>
                    </nav><!-- Main Menu End-->
                </div>
            </div>
        </div><!-- End Sticky Menu -->
    </header>
    <!--End Main Header -->
	
	<!-- Property Search Section Two -->
	<section class="property-search-section-two" style="background-image: url(images/background/4.jpg);">
		<div class="auto-container">
			<div class="content-box">
				<div class="title-box">
					<h2>Find Your Perfect <span>Property</span> For Your Home</h2>
					<h4>We have over million properties for you</h4>
				</div>

				 <div class="property-search-form style-two">
                    <form method="post" action="http://expert-themes.com/html/willies/index.html">
                        <div class="row no-gutters">
                            <!-- Form Group -->
                            <div class="form-group col-lg-2 col-md-6 col-sm-12">
                                <select class="custom-select-box">
                                    <option>Location</option>
                                    <option>New York</option>
                                    <option>Los Angeles</option>
                                    <option>Chicago</option>
                                    <option>Houston</option>
                                </select>
                            </div>

                            <!-- Form Group -->
                            <div class="form-group col-lg-2 col-md-6 col-sm-12">
                                <select class="custom-select-box">
                                    <option>Property Type</option>
                                    <option>Residential</option>
                                    <option>Commercial</option>
                                    <option>Industrial</option>
                                    <option>Apartments</option>
                                </select>
                            </div>

                            <!-- Form Group -->
                            <div class="form-group col-lg-2 col-md-6 col-sm-12">
                                <select class="custom-select-box">
                                    <option>Property Status</option>
                                    <option>For Rent</option>
                                    <option>For Sale</option>
                                </select>
                            </div>


                            <!-- Form Group -->
                            <div class="form-group col-lg-2 col-md-6 col-sm-12">
                                <select class="custom-select-box">
                                    <option>Any Bedrooms</option>
                                    <option>01 Bedroom</option>
                                    <option>02 Bedrooms</option>
                                    <option>03 Bedrooms</option>
                                    <option>04 Bedrooms</option>
                                    <option>05 Bedrooms</option>
                                </select>
                            </div>

                            <!-- Form Group -->
                            <div class="form-group col-lg-2 col-md-6 col-sm-12">
                                <select class="custom-select-box">
                                    <option>Any Bathrooms</option>
                                    <option>01 Bathroom</option>
                                    <option>02 Bathrooms</option>
                                    <option>03 Bathrooms</option>
                                    <option>04 Bathrooms</option>
                                    <option>05 Bathrooms</option>
                                </select>
                            </div>

                            <!-- Form Group -->
                            <div class="form-group col-lg-2 col-md-6 col-sm-12">
                                <button type="submit" class="theme-btn btn-style-one">Search</button>
                            </div>
                        </div>
                    </form>
                </div>
			</div>
		</div>
	</section>
	<!--End Property Search Section Two -->    

    <!-- Property Section Two -->
    <section class="property-section-two">
    	<div class="auto-container">
    		<div class="sec-title">
    			<span class="title">FIND NOW YOUR DREEM HOUSE</span>
    			<h2>About New Property</h2>
    		</div>

    		<div class="property-carousel owl-carousel owl-theme">
    			<!-- New Property -->
    			<div class="new-property">
		    		<div class="row">
		    			<!-- Content Column -->
		    			<div class="content-column col-lg-6 col-md-12 col-sm-12">
		    				<div class="inner-column">
		    					<span class="status">FOR SALE</span>
		    					<h3><a href="property-detail.html">Independent Apartment With Modern Design</a></h3>
		    					<div class="start-from"><span>START FROM</span> $ 356,354</div>
		    					<div class="lucation"><i class="la la-map-marker"></i>Orland Park, IL 35785, Chicago, United State</div>

		    					<div class="text">Temporibus autem quibusdam et aut officiis debitis is aut rerum necessitatibus saepes eveniet ut etes seo lage voluptates repudiandae sint et molestiae non mes for Creating futures through building pres Creating preservation etes quibusdam.</div>

		    					<ul class="property-info clearfix">
		                            <li><i class="flaticon-dimension"></i> 356 Sq-Ft</li>
		                            <li><i class="flaticon-bed"></i> 4 Bedrooms</li>
		                            <li><i class="flaticon-car"></i> 2 Garage</li>
		                            <li><i class="flaticon-bathtub"></i> 3 Bathroom</li>
		                        </ul>
		    				</div>
		    			</div>

		    			<!-- Image column -->
		    			<div class="image-column col-lg-6 col-md-12 col-sm-12">
		    				<div class="inner-column">
		    					<figure class="image"><a href="images/resource/image-3.jpg" class="lightbox-image" data-fancybox="images"><img src="images/resource/image-3.jpg" alt=""></a></figure>
		    				</div>
		    			</div>
		    		</div>
    			</div>

    			<!-- New Property -->
    			<div class="new-property">
		    		<div class="row">
		    			<!-- Content Column -->
		    			<div class="content-column col-lg-6 col-md-12 col-sm-12">
		    				<div class="inner-column">
		    					<span class="status">FOR SALE</span>
		    					<h3><a href="property-detail.html">Independent Apartment With Modern Design</a></h3>
		    					<div class="start-from"><span>START FROM</span> $ 356,354</div>
		    					<div class="lucation"><i class="la la-map-marker"></i>Orland Park, IL 35785, Chicago, United State</div>

		    					<div class="text">Temporibus autem quibusdam et aut officiis debitis is aut rerum necessitatibus saepes eveniet ut etes seo lage voluptates repudiandae sint et molestiae non mes for Creating futures through building pres Creating preservation etes quibusdam.</div>

		    					<ul class="property-info clearfix">
		                            <li><i class="flaticon-dimension"></i> 356 Sq-Ft</li>
		                            <li><i class="flaticon-bed"></i> 4 Bedrooms</li>
		                            <li><i class="flaticon-car"></i> 2 Garage</li>
		                            <li><i class="flaticon-bathtub"></i> 3 Bathroom</li>
		                        </ul>
		    				</div>
		    			</div>

		    			<!-- Image column -->
		    			<div class="image-column col-lg-6 col-md-12 col-sm-12">
		    				<div class="inner-column">
		    					<figure class="image"><a href="images/resource/image-3.jpg" class="lightbox-image" data-fancybox="images"><img src="images/resource/image-3.jpg" alt=""></a></figure>
		    				</div>
		    			</div>
		    		</div>
    			</div>
    		</div>
    	</div>
    </section>
    <!--End Property Section Two -->

    <!-- Fun Fact -->
    <section class="fun-facts-section" style="background-image:url(images/background/6.jpg);">
        <div class="auto-container">
            <div class="video-box">
            	 <figure class="image"><img src="images/resource/image-5.jpg" alt="">
                    <a href="https://www.youtube.com/watch?v=Fvae8nxzVz4" class="link" data-fancybox="gallery" data-caption=""><span class="icon flaticon-play-button-3"></span></a>
                </figure>
            </div>

            <div class="fun-facts">
	            <div class="row clearfix">
	                <!--Column-->
	                <div class="column count-box col-lg-3 col-md-6 col-sm-12">
                        <div class="content">
                            <div class="icon-box"><span class="la la-home"></span></div>
                            <div class="count-outer count-box">
                                <span class="count-text" data-speed="3000" data-stop="300">0 </span>
                            </div>
                            <div class="counter-title">Sold Houses</div>
                        </div>
	                </div>
	                

	                <!--Column-->
	                <div class="column count-box col-lg-3 col-md-6 col-sm-12">
                        <div class="content">
                            <div class="icon-box"><span class="la la-th-list"></span></div>
                            <div class="count-outer count-box">
                                <span class="count-text" data-speed="2000" data-stop="470">0 </span>
                            </div>
                            <div class="counter-title">Daily Listings</div>
                        </div>
	                </div>
	                

	                <!--Column-->
	                <div class="column count-box col-lg-3 col-md-6 col-sm-12">
                        <div class="content">
                            <div class="icon-box"><span class="la la-user-secret"></span></div>
                            <div class="count-outer count-box">
                                <span class="count-text" data-speed="2000" data-stop="250">0 </span>
                            </div>
                            <div class="counter-title">Expert Agents</div>
                        </div>
	                </div>
	                
	                <!--Column-->
	                <div class="column count-box col-lg-3 col-md-6 col-sm-12">
                        <div class="content">
                            <div class="icon-box"><span class="la la-trophy"></span></div>
                            <div class="count-outer count-box">
                                <span class="count-text" data-speed="3000" data-stop="200">0 </span>
                            </div>
                            <div class="counter-title">Won Awards</div>
                        </div>
	                </div>
	            </div>
            </div>
        </div>
    </section>
    <!-- End Fun Fact -->

    <!-- Services Section -->
    <section class="services-section">
    	<div class="auto-container">
    		<div class="sec-title">
    			<span class="title">we offer the best real estate</span>
    			<h2>Property Services</h2>
    		</div>

    		<div class="row">
    			<!-- Service Block -->
    			<div class="service-block col-lg-4 col-md-6 col-sm-12">
    				<div class="inner-box">
    					<div class="icon-box"><span class="icon flaticon-buildings"></span></div>
    					<h4><a href="property-detail.html">Houses</a></h4>
    					<div class="text">Nonec pede justo fringilla vel aliquet nec vulputate eget arcu in enim justo rhoncus ut imperdiet venenatis vitae justo.</div>
    					<div class="link-box"><a href="property-detail.html">Read More</a></div>
    				</div>
    			</div>

    			<!-- Service Block -->
    			<div class="service-block col-lg-4 col-md-6 col-sm-12">
    				<div class="inner-box">
    					<div class="icon-box"><span class="icon flaticon-apartment-1"></span></div>
    					<h4><a href="property-detail.html">apartments</a></h4>
    					<div class="text">Nonec pede justo fringilla vel aliquet nec vulputate eget arcu in enim justo rhoncus ut imperdiet venenatis vitae justo.</div>
    					<div class="link-box"><a href="property-detail.html">Read More</a></div>
    				</div>
    			</div>

    			<!-- Service Block -->
    			<div class="service-block col-lg-4 col-md-6 col-sm-12">
    				<div class="inner-box">
    					<div class="icon-box"><span class="icon flaticon-urban"></span></div>
    					<h4><a href="property-detail.html">Commercial</a></h4>
    					<div class="text">Nonec pede justo fringilla vel aliquet nec vulputate eget arcu in enim justo rhoncus ut imperdiet venenatis vitae justo.</div>
    					<div class="link-box"><a href="property-detail.html">Read More</a></div>
    				</div>
    			</div>

    			<!-- Service Block -->
    			<div class="service-block col-lg-4 col-md-6 col-sm-12">
    				<div class="inner-box">
    					<div class="icon-box"><span class="icon flaticon-house-1"></span></div>
    					<h4><a href="property-detail.html">Renting & Selling</a></h4>
    					<div class="text">Nonec pede justo fringilla vel aliquet nec vulputate eget arcu in enim justo rhoncus ut imperdiet venenatis vitae justo.</div>
    					<div class="link-box"><a href="property-detail.html">Read More</a></div>
    				</div>
    			</div>

    			<!-- Service Block -->
    			<div class="service-block col-lg-4 col-md-6 col-sm-12">
    				<div class="inner-box">
    					<div class="icon-box"><span class="icon flaticon-settings-2"></span></div>
    					<h4><a href="property-detail.html">Management</a></h4>
    					<div class="text">Nonec pede justo fringilla vel aliquet nec vulputate eget arcu in enim justo rhoncus ut imperdiet venenatis vitae justo.</div>
    					<div class="link-box"><a href="property-detail.html">Read More</a></div>
    				</div>
    			</div>

    			<!-- Service Block -->
    			<div class="service-block col-lg-4 col-md-6 col-sm-12">
    				<div class="inner-box">
    					<div class="icon-box"><span class="icon flaticon-file-1"></span></div>
    					<h4><a href="property-detail.html">Property Listing</a></h4>
    					<div class="text">Nonec pede justo fringilla vel aliquet nec vulputate eget arcu in enim justo rhoncus ut imperdiet venenatis vitae justo.</div>
    					<div class="link-box"><a href="property-detail.html">Read More</a></div>
    				</div>
    			</div>
    		</div>
    	</div>
    </section>
    <!--End Services Section -->

    <!--Popular Places Section-->
    <section class="popular-places-section-two" style="background-image: url(images/background/7.jpg);">
        <div class="auto-container">
            <div class="sec-title light">
                <span class="title">FIND YOUR DREAM HOUSE IN YOUR CITY</span>
                <h2>MOST POPULAR PLACES</h2>
            </div>
        </div>

        <div class="popular-places-carousel owl-carousel owl-theme">
        	<!-- Popular item two -->
        	<div class="popular-item-two">
        		<div class="inner-box">
        			<div class="image-box">
        				<figure class="image"><img src="images/gallery/2-1.jpg" alt=""></figure>
        				<div class="overlay-box">
                            <h3 class="place"><a href="properties.html">New York City</a></h3>
                            <div class="view-all"><a href="properties.html">View All</a></div>
                        </div>
        			</div>
        			<div class="info-box">
        				<h4 class="category"><a href="properties.html">Demanding Farm</a></h4>
        				<span class="properties">3 Properties</span>
        			</div>
        		</div>
        	</div>

        	<!-- Popular item two -->
        	<div class="popular-item-two">
        		<div class="inner-box">
        			<div class="image-box">
        				<figure class="image"><img src="images/gallery/2-2.jpg" alt=""></figure>
        				<div class="overlay-box">
                            <h3 class="place"><a href="properties.html">New York City</a></h3>
                            <div class="view-all"><a href="properties.html">View All</a></div>
                        </div>
        			</div>
        			<div class="info-box">
        				<h4 class="category"><a href="properties.html">Laxury Apartment</a></h4>
        				<span class="properties">7 Properties</span>
        			</div>
        		</div>
        	</div>

        	<!-- Popular item two -->
        	<div class="popular-item-two">
        		<div class="inner-box">
        			<div class="image-box">
        				<figure class="image"><img src="images/gallery/2-3.jpg" alt=""></figure>
        				<div class="overlay-box">
                            <h3 class="place"><a href="properties.html">New York City</a></h3>
                            <div class="view-all"><a href="properties.html">View All</a></div>
                        </div>
        			</div>
        			<div class="info-box">
        				<h4 class="category"><a href="properties.html">Great Restaurant</a></h4>
        				<span class="properties">5 Properties</span>
        			</div>
        		</div>
        	</div>

        	<!-- Popular item two -->
        	<div class="popular-item-two">
        		<div class="inner-box">
        			<div class="image-box">
        				<figure class="image"><img src="images/gallery/2-4.jpg" alt=""></figure>
        				<div class="overlay-box">
                            <h3 class="place"><a href="properties.html">New York City</a></h3>
                            <div class="view-all"><a href="properties.html">View All</a></div>
                        </div>
        			</div>
        			<div class="info-box">
        				<h4 class="category"><a href="properties.html">Demanding Farm</a></h4>
        				<span class="properties">3 Properties</span>
        			</div>
        		</div>
        	</div>

        	<!-- Popular item two -->
        	<div class="popular-item-two">
        		<div class="inner-box">
        			<div class="image-box">
        				<figure class="image"><img src="images/gallery/2-5.jpg" alt=""></figure>
        				<div class="overlay-box">
                            <h3 class="place"><a href="properties.html">New York City</a></h3>
                            <div class="view-all"><a href="properties.html">View All</a></div>
                        </div>
        			</div>
        			<div class="info-box">
        				<h4 class="category"><a href="properties.html">Beautiful Villa</a></h4>
        				<span class="properties">6 Properties</span>
        			</div>
        		</div>
        	</div>

        	<!-- Popular item two -->
        	<div class="popular-item-two">
        		<div class="inner-box">
        			<div class="image-box">
        				<figure class="image"><img src="images/gallery/2-2.jpg" alt=""></figure>
        				<div class="overlay-box">
                            <h3 class="place"><a href="properties.html">New York City</a></h3>
                            <div class="view-all"><a href="properties.html">View All</a></div>
                        </div>
        			</div>
        			<div class="info-box">
        				<h4 class="category"><a href="properties.html">Laxury House</a></h4>
        				<span class="properties">8 Properties</span>
        			</div>
        		</div>
        	</div>
        </div>
    </section>
    <!--Portfolio Section-->

    <!-- News Section -->
    <section class="news-section-two">
        <div class="auto-container">
            <div class="sec-title">
                <span class="title">ALL ABOUT LATEST WILLIA UPDATES</span>
                <h2>NEWS & STORIES</h2>
            </div>

            <div class="row">
            	<!-- News Block Two -->
            	<div class="news-block-two col-lg-6 col-md-6 col-sm-12">
            		<div class="inner-box">
            			<div class="image-box">
            				<figure class="image"><a href="blog-detail.html"><img src="images/resource/news-4.jpg" alt=""></a></figure>
            			</div>

            			<div class="content-box">
            				<h4><a href="blog-detail.html">Resources that we thought you may find useful property</a></h4>
            				<div class="text">Alternatively if you have a specific service or questio in mind please don’t hesitate to ...</div>
            				<ul class="info clearfix">
            					<li><i class="la la-user"></i> Khuram Arshad</li>
            					<li><i class="la la-calendar"></i> 21 Feb, 2018</li>
            				</ul>
            			</div>
            		</div>
            	</div>

            	<!-- News Block Two -->
            	<div class="news-block-two col-lg-6 col-md-6 col-sm-12">
            		<div class="inner-box">
            			<div class="image-box">
            				<figure class="image"><a href="blog-detail.html"><img src="images/resource/news-5.jpg" alt=""></a></figure>
            			</div>

            			<div class="content-box">
            				<h4><a href="blog-detail.html">Resources that we thought you may find useful property</a></h4>
            				<div class="text">Alternatively if you have a specific service or questio in mind please don’t hesitate to ...</div>
            				<ul class="info clearfix">
            					<li><i class="la la-user"></i> Khuram Arshad</li>
            					<li><i class="la la-calendar"></i> 21 Feb, 2018</li>
            				</ul>
            			</div>
            		</div>
            	</div>

            	<!-- News Block Two -->
            	<div class="news-block-two col-lg-6 col-md-6 col-sm-12">
            		<div class="inner-box">
            			<div class="image-box">
            				<figure class="image"><a href="blog-detail.html"><img src="images/resource/news-6.jpg" alt=""></a></figure>
            			</div>

            			<div class="content-box">
            				<h4><a href="blog-detail.html">A new residential project launched Find the right property</a></h4>
            				<div class="text">Alternatively if you have a specific service or questio in mind please don’t hesitate to ...</div>
            				<ul class="info clearfix">
            					<li><i class="la la-user"></i> Khuram Arshad</li>
            					<li><i class="la la-calendar"></i> 21 Feb, 2018</li>
            				</ul>
            			</div>
            		</div>
            	</div>

            	<!-- News Block Two -->
            	<div class="news-block-two col-lg-6 col-md-6 col-sm-12">
            		<div class="inner-box">
            			<div class="image-box">
            				<figure class="image"><a href="blog-detail.html"><img src="images/resource/news-7.jpg" alt=""></a></figure>
            			</div>

            			<div class="content-box">
            				<h4><a href="blog-detail.html">A new residential project launched Find the right property</a></h4>
            				<div class="text">Alternatively if you have a specific service or questio in mind please don’t hesitate to ...</div>
            				<ul class="info clearfix">
            					<li><i class="la la-user"></i> Khuram Arshad</li>
            					<li><i class="la la-calendar"></i> 21 Feb, 2018</li>
            				</ul>
            			</div>
            		</div>
            	</div>
            </div>
        </div>
    </section>
    <!--End News Section -->

    <!-- Testimonial Section -->
    <section class="testimonial-section" style="background-image: url(images/background/8.jpg);">
    	<div class="auto-container">
    		<div class="sec-title light">
    			<span class="title">Testimonials</span>
    			<h2>what clients says</h2>
    		</div>

    		<div class="testimonial-carousel owl-carousel owl-theme">
    			<!-- Testimonial Block -->
    			<div class="testimonial-block">
    				<div class="inner-box">
    					<div class="image-box">
    						<figure class="image"><img src="images/resource/thumb-3.jpg" alt=""></figure>
    					</div>
    					<div class="content-box">
    						<h4 class="name">John Doe</h4>
    						<span class="city">New York</span>
    						<div class="text">Leverage agile frameworks to provide a robust synopsis for high level overviews. Organically grow the holistic world view of disruptive diversity.</div>
    						<div class="rating">
    							<span class="la la-star"></span><span class="la la-star"></span><span class="la la-star"></span><span class="la la-star"></span><span class="la la-star-o"></span>
    						</div>
    						<span class="icon la la-quote-left"></span>
    					</div>
    				</div>
    			</div>

    			<!-- Testimonial Block -->
    			<div class="testimonial-block">
    				<div class="inner-box">
    					<div class="image-box">
    						<figure class="image"><img src="images/resource/thumb-4.jpg" alt=""></figure>
    					</div>
    					<div class="content-box">
    						<h4 class="name">Olivia Evie</h4>
    						<span class="city">New York</span>
    						<div class="text">Leverage agile frameworks to provide a robust synopsis for high level overviews. Organically grow the holistic world view of disruptive diversity.</div>
    						<div class="rating">
    							<span class="la la-star"></span><span class="la la-star"></span><span class="la la-star"></span><span class="la la-star"></span><span class="la la-star-o"></span>
    						</div>
    						<span class="icon la la-quote-left"></span>
    					</div>
    				</div>
    			</div>
    		</div>
    	</div>
    </section>
    <!--End Testimonial Section -->

    <!--Clients Section-->
    <section class="clients-section style-two">
        <div class="auto-container">
            <div class="sponsors-outer">
                <!--Sponsors Carousel-->
                <ul class="sponsors-carousel owl-carousel owl-theme">
                    <li class="slide-item"><figure class="image-box"><a href="#"><img src="images/clients/1.png" alt=""></a></figure></li>
                    <li class="slide-item"><figure class="image-box"><a href="#"><img src="images/clients/2.png" alt=""></a></figure></li>
                    <li class="slide-item"><figure class="image-box"><a href="#"><img src="images/clients/3.png" alt=""></a></figure></li>
                    <li class="slide-item"><figure class="image-box"><a href="#"><img src="images/clients/4.png" alt=""></a></figure></li>
                    <li class="slide-item"><figure class="image-box"><a href="#"><img src="images/clients/1.png" alt=""></a></figure></li>
                    <li class="slide-item"><figure class="image-box"><a href="#"><img src="images/clients/2.png" alt=""></a></figure></li>
                    <li class="slide-item"><figure class="image-box"><a href="#"><img src="images/clients/3.png" alt=""></a></figure></li>
                    <li class="slide-item"><figure class="image-box"><a href="#"><img src="images/clients/4.png" alt=""></a></figure></li>
                </ul>
            </div>
        </div>
    </section>
    <!--End Clients Section-->

    <!-- Contact Section -->
    <section class="contact-section">
    	<div class="outer-container clearfix">

    		<!-- Form Column -->
    		<div class="form-column">
    			<div class="inner-column">
    				<div class="title-box">
    					<span class="title">How To</span>
    					<h2>Contact Us</h2>
    					<div class="text">Don’t Hesitate to Contact with us for any kind of information</div>
    				</div>

    				<!-- Contact Form -->
		            <div class="contact-form">
		                <form method="post" action="http://expert-themes.com/html/willies/sendemail.php" id="contact-form">
	                        <div class="form-group">
	                            <input type="text" name="username" placeholder="Name" required>
	                        </div>
	                        
	                        <div class="form-group">
	                            <input type="email" name="email" placeholder="Email" required>
	                        </div>

	                        <div class="form-group">
	                            <input type="text" name="subject" placeholder="Subject" required>
	                        </div>

	                        <div class="form-group">
	                            <textarea name="message" placeholder="Massage"></textarea>
	                        </div>
	                        
	                        <div class="form-group">
	                            <button class="theme-btn btn-style-one" type="submit" name="submit-form">Send Now</button>
	                        </div> 
		                </form>
		            </div>
    			</div>
    		</div>

                        <!-- Info Column -->
            <div class="info-column">
                <div class="inner-column">
                    <!-- Info Box -->
                    <div class="contact-info-box">
                        <div class="inner-box">
                            <span class="icon la la-phone"></span>
                            <h4>Phones</h4>
                            <ul>
                                <li>88 867 56 453</li>
                                <li>21 535 42 546</li>
                            </ul>
                        </div>
                    </div>

                    <!-- Info Box -->
                    <div class="contact-info-box">
                        <div class="inner-box">
                            <span class="icon la la-envelope-o"></span>
                            <h4>Emails</h4>
                            <ul>
                                <li>info@yousite.com</li>
                                <li>sale@yousite.com</li>
                            </ul>
                        </div>
                    </div>

                    <!-- Info Box -->
                    <div class="contact-info-box">
                        <div class="inner-box">
                            <span class="icon la la-globe"></span>
                            <h4>Address</h4>
                            <ul>
                                <li>123 Ipsum Ave, Lorem City, <br> Dolor Country, Thw World</li>
                            </ul> 
                        </div>
                    </div>

                    <!-- Info Box -->
                    <div class="contact-info-box follow-us">
                        <div class="inner-box">
                            <h4>Follow Us:</h4>
                            <ul class="social-icon-three">
                                <li><a href="#"><span class="la la-facebook-f"></span></a></li>
                                <li><a href="#"><span class="la la-twitter"></span></a></li>
                                <li><a href="#"><span class="la la-google-plus"></span></a></li>
                                <li><a href="#"><span class="la la-dribbble"></span></a></li>
                                <li><a href="#"><span class="la la-pinterest"></span></a></li>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>

    		<!-- Map Column -->
    		<div class="map-column">
    			<div class="map-outer">
		            <!--Map Canvas-->
		            <div class="map-canvas"
		                data-zoom="12"
		                data-lat="-37.817085"
		                data-lng="144.955631"
		                data-type="roadmap"
		                data-hue="#ffc400"
		                data-title="Envato"
		                data-icon-path="images/icons/map-marker.png"
		                data-content="Melbourne VIC 3000, Australia<br><a href='mailto:info@youremail.com'>info@youremail.com</a>">
		            </div>
		        </div>
		    </div>


    	</div>
    </section>
    <!--End Contact Section -->

    <!-- Main Footer -->
    <footer class="main-footer style-two">
        <!--Footer Bottom-->
        <div class="footer-bottom">
            <div class="auto-container">
                <div class="inner-container clearfix">
                    <div class="footer-nav">
                        <ul class="clearfix">
                           <li><a href="index-2.html">Home</a></li> 
                           <li><a href="properties.html">Properties</a></li> 
                           <li><a href="properties.html">Agencies</a></li> 
                           <li><a href="agents.html">Agent</a></li> 
                           <li><a href="blog.html">Blogs</a></li> 
                           <li><a href="contact.html">Contact</a></li> 
                        </ul>
                    </div>
                                                                      
                    <!--Scroll to top-->
                    <div class="scroll-to-top scroll-to-target" data-target="html"><span class="la la-angle-double-up"></span></div>
                    
                    <div class="copyright-text">
                        <p><a target="_blank" href="https://www.templateshub.net">Templates Hub</a></p>
                    </div>
                </div>
            </div>
        </div>
    </footer>
    <!-- End Main Footer -->

</div>
<!--End pagewrapper-->

<!-- Color Palate / Color Switcher -->
<div class="color-palate">
    <div class="color-trigger">
        <i class="la la-cog"></i>
    </div>
    <div class="color-palate-head">
        <h6>Choose Your Color</h6>
    </div>
    <div class="various-color clearfix">
        <div class="colors-list">
            <span class="palate default-color active" data-theme-file="css/color-themes/default-theme.css"></span>
            <span class="palate green-color" data-theme-file="css/color-themes/green-theme.css"></span>
            <span class="palate blue-color" data-theme-file="css/color-themes/blue-theme.css"></span>
            <span class="palate orange-color" data-theme-file="css/color-themes/orange-theme.css"></span>
            <span class="palate purple-color" data-theme-file="css/color-themes/purple-theme.css"></span>
            <span class="palate teal-color" data-theme-file="css/color-themes/teal-theme.css"></span>
            <span class="palate brown-color" data-theme-file="css/color-themes/brown-theme.css"></span>
            <span class="palate redd-color" data-theme-file="css/color-themes/redd-color.css"></span>
        </div>
    </div>
    <ul class="box-version option-box"> <li>Full width</li> <li class="box">Boxed</li> </ul>
    <ul class="rtl-version option-box"> <li>LTR Version</li> <li class="rtl">RTL Version</li> </ul>
    <div class="palate-foo">
        <span>You will find much more options for colors and styling in admin panel. This color picker is used only for demonstation purposes.</span>
    </div>
    <a href="#" class="purchase-btn">Purchase now $17</a>
</div><!-- End Color Switcher -->

<script src="js/jquery.js"></script> 
<script src="js/popper.min.js"></script>
<script src="js/bootstrap.min.js"></script>
<script src="js/jquery-ui.js"></script>
<script src="js/jquery.fancybox.js"></script>
<script src="js/owl.js"></script>
<script src="js/wow.js"></script>
<script src="js/isotope.js"></script>
<script src="js/appear.js"></script>
<script src="js/validate.js"></script>
<script src="js/script.js"></script>
<!--Google Map APi Key-->
<script src="https://maps.googleapis.com/maps/api/js?key=AIzaSyBjirg3UoMD5oUiFuZt3P9sErZD-2Rxc68"></script>
<script src="js/map-script.js"></script>
<!--End Google Map APi-->
<!-- Color Setting -->
<script src="js/color-settings.js"></script>
</body>

</html>